pub enum Descriptor {
Bluetooth(BluetoothDescriptor),
Lan(LanDescriptor),
Unknown(UnknownDescriptor),
}Expand description
A transport descriptor
Variants
Bluetooth(BluetoothDescriptor)
A Bluetooth transport descriptor
Lan(LanDescriptor)
A LAN transport descriptor
Unknown(UnknownDescriptor)
An unknown transport descriptor
Implementations
Sourceimpl Descriptor
impl Descriptor
Sourcepub fn bluetooth() -> Descriptor
pub fn bluetooth() -> Descriptor
Creates a new Bluetooth transport descriptor without a known address.
Sourcepub fn bluetooth_address(address: [u8; 6]) -> Descriptor
pub fn bluetooth_address(address: [u8; 6]) -> Descriptor
Creates a new Bluetooth transport descriptor with a known address.