pub struct BluetoothDescriptor { /* private fields */ }Expand description
A Bluetooth transport descriptor
Implementations
Sourceimpl BluetoothDescriptor
impl BluetoothDescriptor
Sourcepub fn new() -> BluetoothDescriptor
pub fn new() -> BluetoothDescriptor
Creates a new bluetooth transport descriptor without a known address.
Sourcepub fn with_address(address: [u8; 6]) -> BluetoothDescriptor
pub fn with_address(address: [u8; 6]) -> BluetoothDescriptor
Creates a new bluetooth transport descriptor with a known address.